@@ -15,6 +15,14 @@ pillar_shaft.quietly_mapped <- function(x, ...) {
     width = 7, min_width = 7, na_indent = 0)
 }
 
+#' @importFrom pillar pillar_shaft
+#' @export
+pillar_shaft.peacefully_mapped <- function(x, ...) {
+  out <- format(x)
+  pillar::new_pillar_shaft_simple(out, align = "left",
+    width = 9, min_width = 9, na_indent = 0)
+}
+
 # -----------------------------------------------------------------------------
 
 #' @importFrom pillar type_sum
@@ -24,3 +32,7 @@ type_sum.safely_mapped <- function(x) { "collat" }
 #' @importFrom pillar type_sum
 #' @export
 type_sum.quietly_mapped <- function(x) { "collat" }
+
+#' @importFrom pillar type_sum
+#' @export
+type_sum.peacefully_mapped <- function(x) { "collat" }
